@@ -157,6 +157,33 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         """
         return self._transport
 
+    @staticmethod
+    def access_level_path(access_policy: str, access_level: str,) -> str:
+        """Returns a fully-qualified access_level string."""
+        return "accessPolicies/{access_policy}/accessLevels/{access_level}".format(
+            access_policy=access_policy, access_level=access_level,
+        )
+
+    @staticmethod
+    def parse_access_level_path(path: str) -> Dict[str, str]:
+        """Parses a access_level path into its component segments."""
+        m = re.match(
+            r"^accessPolicies/(?P<access_policy>.+?)/accessLevels/(?P<access_level>.+?)$",
+            path,
+        )
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def access_policy_path(access_policy: str,) -> str:
+        """Returns a fully-qualified access_policy string."""
+        return "accessPolicies/{access_policy}".format(access_policy=access_policy,)
+
+    @staticmethod
+    def parse_access_policy_path(path: str) -> Dict[str, str]:
+        """Parses a access_policy path into its component segments."""
+        m = re.match(r"^accessPolicies/(?P<access_policy>.+?)$", path)
+        return m.groupdict() if m else {}
+
     @staticmethod
     def asset_path() -> str:
         """Returns a fully-qualified asset string."""
@@ -173,6 +200,22 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/feeds/(?P<feed>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @staticmethod
+    def service_perimeter_path(access_policy: str, service_perimeter: str,) -> str:
+        """Returns a fully-qualified service_perimeter string."""
+        return "accessPolicies/{access_policy}/servicePerimeters/{service_perimeter}".format(
+            access_policy=access_policy, service_perimeter=service_perimeter,
+        )
+
+    @staticmethod
+    def parse_service_perimeter_path(path: str) -> Dict[str, str]:
+        """Parses a service_perimeter path into its component segments."""
+        m = re.match(
+            r"^accessPolicies/(?P<access_policy>.+?)/servicePerimeters/(?P<service_perimeter>.+?)$",
+            path,
+        )
+        return m.groupdict() if m else {}
+
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
         """Returns a fully-qualified billing_account string."""
@@ -346,6 +389,10 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=(
+                    Transport == type(self).get_transport_class("grpc")
+                    or Transport == type(self).get_transport_class("grpc_asyncio")
+                ),
             )
 
     def export_assets(
@@ -1001,8 +1048,8 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
                    the word "key".
                 -  ``state:ACTIVE`` to find Cloud resources whose state
                    contains "ACTIVE" as a word.
-                -  ``NOT state:ACTIVE`` to find {{gcp_name}} resources
-                   whose state doesn't contain "ACTIVE" as a word.
+                -  ``NOT state:ACTIVE`` to find Cloud resources whose
+                   state doesn't contain "ACTIVE" as a word.
                 -  ``createTime<1609459200`` to find Cloud resources
                    that were created before "2021-01-01 00:00:00 UTC".
                    1609459200 is the epoch timestamp of "2021-01-01
@@ -1332,8 +1379,8 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         [google.longrunning.Operation][google.longrunning.Operation],
         which allows you to track the operation status. We recommend
         intervals of at least 2 seconds with exponential backoff retry
-        to poll the operation result. The metadata contains the request
-        to help callers to map responses to requests.
+        to poll the operation result. The metadata contains the metadata
+        for the long-running operation.
 
         Args:
             request (google.cloud.asset_v1.types.AnalyzeIamPolicyLongrunningRequest):
@@ -1385,12 +1432,68 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
             response,
             self._transport.operations_client,
             asset_service.AnalyzeIamPolicyLongrunningResponse,
-            metadata_type=asset_service.AnalyzeIamPolicyLongrunningRequest,
+            metadata_type=asset_service.AnalyzeIamPolicyLongrunningMetadata,
         )
 
         # Done; return the response.
         return response
 
+    def analyze_move(
+        self,
+        request: asset_service.AnalyzeMoveRequest = None,
+        *,
+        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> asset_service.AnalyzeMoveResponse:
+        r"""Analyze moving a resource to a specified destination
+        without kicking off the actual move. The analysis is
+        best effort depending on the user's permissions of
+        viewing different hierarchical policies and
+        configurations. The policies and configuration are
+        subject to change before the actual resource migration
+        takes place.
+
+        Args:
+            request (google.cloud.asset_v1.types.AnalyzeMoveRequest):
+                The request object. The request message for performing
+                resource move analysis.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.asset_v1.types.AnalyzeMoveResponse:
+                The response message for resource
+                move analysis.
+
+        """
+        # Create or coerce a protobuf request object.
+        # Minor optimization to avoid making a copy if the user passes
+        # in a asset_service.AnalyzeMoveRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, asset_service.AnalyzeMoveRequest):
+            request = asset_service.AnalyzeMoveRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[self._transport.analyze_move]
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("resource", request.resource),)),
+        )
+
+        # Send the request.
+        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # Done; return the response.
+        return response
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
