@@ -60,6 +60,9 @@ from .assets import (
     IamPolicyAnalysisResult,
     IamPolicyAnalysisState,
     IamPolicySearchResult,
+    RelatedAsset,
+    RelatedAssets,
+    RelationshipAttributes,
     Resource,
     ResourceSearchResult,
     TemporalAsset,
@@ -112,6 +115,9 @@ __all__ = (
     "IamPolicyAnalysisResult",
     "IamPolicyAnalysisState",
     "IamPolicySearchResult",
+    "RelatedAsset",
+    "RelatedAssets",
+    "RelationshipAttributes",
     "Resource",
     "ResourceSearchResult",
     "TemporalAsset",
