@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,6 +15,8 @@
 #
 
 from .services.asset_service import AssetServiceClient
+from .services.asset_service import AssetServiceAsyncClient
+
 from .types.asset_service import AnalyzeIamPolicyRequest
 from .types.asset_service import AnalyzeIamPolicyResponse
 from .types.asset_service import ExportIamPolicyAnalysisRequest
@@ -24,14 +25,14 @@ from .types.asset_service import IamPolicyAnalysisOutputConfig
 from .types.asset_service import IamPolicyAnalysisQuery
 from .types.assets import IamPolicyAnalysisResult
 
-
 __all__ = (
+    "AssetServiceAsyncClient",
     "AnalyzeIamPolicyRequest",
     "AnalyzeIamPolicyResponse",
+    "AssetServiceClient",
     "ExportIamPolicyAnalysisRequest",
     "ExportIamPolicyAnalysisResponse",
     "IamPolicyAnalysisOutputConfig",
     "IamPolicyAnalysisQuery",
     "IamPolicyAnalysisResult",
-    "AssetServiceClient",
 )
