@@ -154,11 +154,54 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         """
         return self._transport
 
+    @staticmethod
+    def access_level_path(access_policy: str, access_level: str,) -> str:
+        """Returns a fully-qualified access_level string."""
+        return "accessPolicies/{access_policy}/accessLevels/{access_level}".format(
+            access_policy=access_policy, access_level=access_level,
+        )
+
+    @staticmethod
+    def parse_access_level_path(path: str) -> Dict[str, str]:
+        """Parses a access_level path into its component segments."""
+        m = re.match(
+            r"^accessPolicies/(?P<access_policy>.+?)/accessLevels/(?P<access_level>.+?)$",
+            path,
+        )
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def access_policy_path(access_policy: str,) -> str:
+        """Returns a fully-qualified access_policy string."""
+        return "accessPolicies/{access_policy}".format(access_policy=access_policy,)
+
+    @staticmethod
+    def parse_access_policy_path(path: str) -> Dict[str, str]:
+        """Parses a access_policy path into its component segments."""
+        m = re.match(r"^accessPolicies/(?P<access_policy>.+?)$", path)
+        return m.groupdict() if m else {}
+
     @staticmethod
     def asset_path() -> str:
         """Returns a fully-qualified asset string."""
         return "*".format()
 
+    @staticmethod
+    def service_perimeter_path(access_policy: str, service_perimeter: str,) -> str:
+        """Returns a fully-qualified service_perimeter string."""
+        return "accessPolicies/{access_policy}/servicePerimeters/{service_perimeter}".format(
+            access_policy=access_policy, service_perimeter=service_perimeter,
+        )
+
+    @staticmethod
+    def parse_service_perimeter_path(path: str) -> Dict[str, str]:
+        """Parses a service_perimeter path into its component segments."""
+        m = re.match(
+            r"^accessPolicies/(?P<access_policy>.+?)/servicePerimeters/(?P<service_perimeter>.+?)$",
+            path,
+        )
+        return m.groupdict() if m else {}
+
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
         """Returns a fully-qualified billing_account string."""
@@ -332,6 +375,10 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=(
+                    Transport == type(self).get_transport_class("grpc")
+                    or Transport == type(self).get_transport_class("grpc_asyncio")
+                ),
             )
 
     def list_assets(
