@@ -115,16 +115,6 @@ def test_asset_service_client_from_service_account_info(client_class):
         assert client.transport._host == "cloudasset.googleapis.com:443"
 
 
-@pytest.mark.parametrize("client_class", [AssetServiceClient, AssetServiceAsyncClient,])
-def test_asset_service_client_service_account_always_use_jwt(client_class):
-    with mock.patch.object(
-        service_account.Credentials, "with_always_use_jwt_access", create=True
-    ) as use_jwt:
-        creds = service_account.Credentials(None, None, None)
-        client = client_class(credentials=creds)
-        use_jwt.assert_not_called()
-
-
 @pytest.mark.parametrize(
     "transport_class,transport_name",
     [
@@ -132,7 +122,7 @@ def test_asset_service_client_service_account_always_use_jwt(client_class):
         (transports.AssetServiceGrpcAsyncIOTransport, "grpc_asyncio"),
     ],
 )
-def test_asset_service_client_service_account_always_use_jwt_true(
+def test_asset_service_client_service_account_always_use_jwt(
     transport_class, transport_name
 ):
     with mock.patch.object(
@@ -142,6 +132,13 @@ def test_asset_service_client_service_account_always_use_jwt_true(
         transport = transport_class(credentials=creds, always_use_jwt_access=True)
         use_jwt.assert_called_once_with(True)
 
+    with mock.patch.object(
+        service_account.Credentials, "with_always_use_jwt_access", create=True
+    ) as use_jwt:
+        creds = service_account.Credentials(None, None, None)
+        transport = transport_class(credentials=creds, always_use_jwt_access=False)
+        use_jwt.assert_not_called()
+
 
 @pytest.mark.parametrize("client_class", [AssetServiceClient, AssetServiceAsyncClient,])
 def test_asset_service_client_from_service_account_file(client_class):
@@ -218,6 +215,7 @@ def test_asset_service_client_client_options(
             client_cert_source_for_mtls=None,
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
         )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -234,6 +232,7 @@ def test_asset_service_client_client_options(
                 client_cert_source_for_mtls=None,
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
+                always_use_jwt_access=True,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -250,6 +249,7 @@ def test_asset_service_client_client_options(
                 client_cert_source_for_mtls=None,
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
+                always_use_jwt_access=True,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT has
@@ -278,6 +278,7 @@ def test_asset_service_client_client_options(
             client_cert_source_for_mtls=None,
             quota_project_id="octopus",
             client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
         )
 
 
@@ -342,6 +343,7 @@ def test_asset_service_client_mtls_env_auto(
                 client_cert_source_for_mtls=expected_client_cert_source,
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
+                always_use_jwt_access=True,
             )
 
     # Check the case ADC client cert is provided. Whether client cert is used depends on
@@ -375,6 +377,7 @@ def test_asset_service_client_mtls_env_auto(
                         client_cert_source_for_mtls=expected_client_cert_source,
                         quota_project_id=None,
                         client_info=transports.base.DEFAULT_CLIENT_INFO,
+                        always_use_jwt_access=True,
                     )
 
     # Check the case client_cert_source and ADC client cert are not provided.
@@ -396,6 +399,7 @@ def test_asset_service_client_mtls_env_auto(
                     client_cert_source_for_mtls=None,
                     quota_project_id=None,
                     client_info=transports.base.DEFAULT_CLIENT_INFO,
+                    always_use_jwt_access=True,
                 )
 
 
@@ -426,6 +430,7 @@ def test_asset_service_client_client_options_scopes(
             client_cert_source_for_mtls=None,
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
         )
 
 
@@ -456,6 +461,7 @@ def test_asset_service_client_client_options_credentials_file(
             client_cert_source_for_mtls=None,
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
         )
 
 
@@ -473,6 +479,7 @@ def test_asset_service_client_client_options_from_dict():
             client_cert_source_for_mtls=None,
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
         )
 
 
@@ -1157,14 +1164,76 @@ def test_asset_service_transport_channel_mtls_with_adc(transport_class):
             assert transport.grpc_channel == mock_grpc_channel
 
 
+def test_access_level_path():
+    access_policy = "squid"
+    access_level = "clam"
+    expected = "accessPolicies/{access_policy}/accessLevels/{access_level}".format(
+        access_policy=access_policy, access_level=access_level,
+    )
+    actual = AssetServiceClient.access_level_path(access_policy, access_level)
+    assert expected == actual
+
+
+def test_parse_access_level_path():
+    expected = {
+        "access_policy": "whelk",
+        "access_level": "octopus",
+    }
+    path = AssetServiceClient.access_level_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_access_level_path(path)
+    assert expected == actual
+
+
+def test_access_policy_path():
+    access_policy = "oyster"
+    expected = "accessPolicies/{access_policy}".format(access_policy=access_policy,)
+    actual = AssetServiceClient.access_policy_path(access_policy)
+    assert expected == actual
+
+
+def test_parse_access_policy_path():
+    expected = {
+        "access_policy": "nudibranch",
+    }
+    path = AssetServiceClient.access_policy_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_access_policy_path(path)
+    assert expected == actual
+
+
 def test_asset_path():
     expected = "*".format()
     actual = AssetServiceClient.asset_path()
     assert expected == actual
 
 
+def test_service_perimeter_path():
+    access_policy = "cuttlefish"
+    service_perimeter = "mussel"
+    expected = "accessPolicies/{access_policy}/servicePerimeters/{service_perimeter}".format(
+        access_policy=access_policy, service_perimeter=service_perimeter,
+    )
+    actual = AssetServiceClient.service_perimeter_path(access_policy, service_perimeter)
+    assert expected == actual
+
+
+def test_parse_service_perimeter_path():
+    expected = {
+        "access_policy": "winkle",
+        "service_perimeter": "nautilus",
+    }
+    path = AssetServiceClient.service_perimeter_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = AssetServiceClient.parse_service_perimeter_path(path)
+    assert expected == actual
+
+
 def test_common_billing_account_path():
-    billing_account = "squid"
+    billing_account = "scallop"
     expected = "billingAccounts/{billing_account}".format(
         billing_account=billing_account,
     )
@@ -1174,7 +1243,7 @@ def test_common_billing_account_path():
 
 def test_parse_common_billing_account_path():
     expected = {
-        "billing_account": "clam",
+        "billing_account": "abalone",
     }
     path = AssetServiceClient.common_billing_account_path(**expected)
 
@@ -1184,7 +1253,7 @@ def test_parse_common_billing_account_path():
 
 
 def test_common_folder_path():
-    folder = "whelk"
+    folder = "squid"
     expected = "folders/{folder}".format(folder=folder,)
     actual = AssetServiceClient.common_folder_path(folder)
     assert expected == actual
@@ -1192,7 +1261,7 @@ def test_common_folder_path():
 
 def test_parse_common_folder_path():
     expected = {
-        "folder": "octopus",
+        "folder": "clam",
     }
     path = AssetServiceClient.common_folder_path(**expected)
 
@@ -1202,7 +1271,7 @@ def test_parse_common_folder_path():
 
 
 def test_common_organization_path():
-    organization = "oyster"
+    organization = "whelk"
     expected = "organizations/{organization}".format(organization=organization,)
     actual = AssetServiceClient.common_organization_path(organization)
     assert expected == actual
@@ -1210,7 +1279,7 @@ def test_common_organization_path():
 
 def test_parse_common_organization_path():
     expected = {
-        "organization": "nudibranch",
+        "organization": "octopus",
     }
     path = AssetServiceClient.common_organization_path(**expected)
 
@@ -1220,7 +1289,7 @@ def test_parse_common_organization_path():
 
 
 def test_common_project_path():
-    project = "cuttlefish"
+    project = "oyster"
     expected = "projects/{project}".format(project=project,)
     actual = AssetServiceClient.common_project_path(project)
     assert expected == actual
@@ -1228,7 +1297,7 @@ def test_common_project_path():
 
 def test_parse_common_project_path():
     expected = {
-        "project": "mussel",
+        "project": "nudibranch",
     }
     path = AssetServiceClient.common_project_path(**expected)
 
@@ -1238,8 +1307,8 @@ def test_parse_common_project_path():
 
 
 def test_common_location_path():
-    project = "winkle"
-    location = "nautilus"
+    project = "cuttlefish"
+    location = "mussel"
     expected = "projects/{project}/locations/{location}".format(
         project=project, location=location,
     )
@@ -1249,8 +1318,8 @@ def test_common_location_path():
 
 def test_parse_common_location_path():
     expected = {
-        "project": "scallop",
-        "location": "abalone",
+        "project": "winkle",
+        "location": "nautilus",
     }
     path = AssetServiceClient.common_location_path(**expected)
 
